# CatRoyale

Cat based battle royale

## Szükséges verzió:

-   Python 3.10.6

## Telepítés

    >pip install CatRoyale

## Indítás

    >CatRoyale
    (Linuxon ha nem fut, akkor meg kell kerensi a .local/bin mappában)

## Használat

    -irányítás: WASD
    -item felvétele: F
    -item eldobás: Q
    -Étel elfogyasztás: C
    -inventory irányítás: egér görgő
    -támadás: SPACE, Fa és Kőkard +sebzést okoz, ehhez ki kell választani az inventoryban
    -Crafting: E
    -Map ki- és bekapcsolás: M
    -nyilakkal a camera mozgatható (ameddig a fő karakter benne van a képben)

## Ételek:

    Répa: +12 hunger, +1hp
    Eper: +10 hunger, +1hp
    Alma: +10 hunger, +20hp
    Gomba: +50 hunger, -10hp

## Ellenfél ai

    Ételt keres, ha 5x5 blockon belül van ellenfél, akkor oda megy és támad

## Felhasznált képek

-   Enemy macska: https://bowpixel.itch.io/cat-50-animations
-   Player macska: https://bowpixel.itch.io/one-cat
-   Inventory: https://elv-games.itch.io/free-inventory-for-rpg-or-farming-games
-   grass: https://lamorapedia.itch.io/grasslands-free
-   items: https://cheekyinkling.itch.io/shikashis-fantasy-icons-pack

## Kódelemzők

    lásd flake8-errors.txt & prospector.txt
